@@ -23,7 +23,9 @@ from autoblocks._impl.context_vars import test_case_run_context_var
 from autoblocks._impl.testing.api import send_end_test_run
 from autoblocks._impl.testing.api import send_error
 from autoblocks._impl.testing.api import send_eval
+from autoblocks._impl.testing.api import send_github_comment
 from autoblocks._impl.testing.api import send_info_for_alignment_mode
+from autoblocks._impl.testing.api import send_slack_notification
 from autoblocks._impl.testing.api import send_start_grid_search_run
 from autoblocks._impl.testing.api import send_start_test_run
 from autoblocks._impl.testing.api import send_test_case_result
@@ -396,6 +398,12 @@ async def run_test_suite_for_grid_combo(
         test_external_id=test_id,
         run_id=run_id,
     )
+    await all_settled(
+        [
+            send_slack_notification(run_id=run_id),
+            send_github_comment(),
+        ]
+    )
 
 
 async def async_run_test_suite(
